@@ -498,8 +498,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, particles, output_type = "full",
         model$n_states, model$n_etas, seed,
         particles, iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, threads, max_iter, conv_tol,
-        sampling_method,iekf_iter, output_type, 
-        default_update_fn, default_prior_fn)
+        sampling_method,iekf_iter, output_type)
     },
     "pm" = {
       nonlinear_pm_mcmc(t(model$y), model$Z, model$H, model$T,
@@ -509,8 +508,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, particles, output_type = "full",
         model$n_states, model$n_etas, seed,
         particles, iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, threads, max_iter, conv_tol,
-        sampling_method,iekf_iter, output_type, 
-        default_update_fn, default_prior_fn)
+        sampling_method,iekf_iter, output_type)
     },
     "is1" =,
     "is2" =,
@@ -525,8 +523,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, particles, output_type = "full",
         particles, iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, threads, pmatch(mcmc_type, paste0("is", 1:3)),
         sampling_method, max_iter, conv_tol, iekf_iter, 
-        output_type, default_update_fn, 
-        default_prior_fn, FALSE)
+        output_type, FALSE)
     },
     "ekf" = {
       nonlinear_ekf_mcmc(t(model$y), model$Z, model$H, model$T,
@@ -535,8 +532,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, particles, output_type = "full",
         model$known_tv_params, as.integer(model$time_varying),
         model$n_states, model$n_etas, seed,
         iter, burnin, thin, gamma, target_acceptance, S,
-        end_adaptive_phase,  threads, iekf_iter, output_type, 
-        default_update_fn, default_prior_fn)
+        end_adaptive_phase,  threads, iekf_iter, output_type)
     },
     "approx" = {
       nonlinear_is_mcmc(t(model$y), model$Z, model$H, model$T,
@@ -547,8 +543,7 @@ run_mcmc.ssm_nlg <-  function(model, iter, particles, output_type = "full",
         particles, iter, burnin, thin, gamma, target_acceptance, S,
         end_adaptive_phase, threads, 2,
         sampling_method, max_iter, conv_tol, 
-        iekf_iter, output_type, default_update_fn, 
-        default_prior_fn, TRUE)
+        iekf_iter, output_type, TRUE)
     }
   )
   if (output_type == 1) {
