@@ -7,8 +7,7 @@ Rcpp::List ukf_nlg(const arma::mat& y, SEXP Z, SEXP H,
   const arma::mat& known_tv_params, const unsigned int n_states,
   const unsigned int n_etas,  const arma::uvec& time_varying,
   const double alpha, const double beta,
-  const double kappa,
-  const Rcpp::Function update_fn, const Rcpp::Function prior_fn) {
+  const double kappa) {
 
   Rcpp::XPtr<nvec_fnPtr> xpfun_Z(Z);
   Rcpp::XPtr<nmat_fnPtr> xpfun_H(H);
@@ -22,7 +21,7 @@ Rcpp::List ukf_nlg(const arma::mat& y, SEXP Z, SEXP H,
 
   ssm_nlg model(y, *xpfun_Z, *xpfun_H, *xpfun_T, *xpfun_R, *xpfun_Zg, *xpfun_Tg,
     *xpfun_a1, *xpfun_P1,  theta, *xpfun_prior, known_params, known_tv_params, n_states, n_etas,
-    time_varying, update_fn, prior_fn, 1);
+    time_varying, 1);
     
   arma::mat at(model.m, model.n + 1);
   arma::mat att(model.m, model.n);
